===============================
signupto
===============================

Minimalist client library for the sign-up.to HTTP API - http://sign-up.to

* Free software: BSD license

* Home page: https://bitbucket.org/spookylukey/signupto
* Bugs: https://bitbucket.org/spookylukey/signupto/issues?status=new&status=open
* Docs: http://signupto.readthedocs.org/en/latest/


Status
======

This is beta software. It is being used in production, and covers the complete
sign-up.to HTTP API. There may still be improvements and fixes to be made.

If you use this library, let me know (at L.Plant.98@cantab.net), and I can
consult you about improvements. Otherwise I may change things without notice.

There are also no automated tests yet. (Patches welcome!)
